import * as types from '../../types';
import axios from 'axios';
const distributosResource = '/distributors.json';

/**
 * Transforms object of keys into array with id as key
 * @param {object} response data object with keys as ids
 * @returns {array} array of items with ids added to it 
 */
const transformData = (data) => {
    let distributors = [];
    for (let key in data) {
        const distributor = data[key];
        distributor.id = key;
        if (!distributor.contacts) {
            distributor.contacts = [];
        }
        distributors.push(distributor);
    }
    return distributors;
};
export default {
    [types.FETCH_DISTRIBUTORS]: ({commit}) => {
        // TODO: Add validation
        axios.get(distributosResource)
            .then( responce => {
                const list = transformData(responce.data);
                commit(types.UPDATE_DISTRIBUTORS, list);
            }).catch( error => {
                console.log(error)
            });
    },
    [types.CLEAR_DISTRIBUTORS]: ({commit}) => {
        commit(types.UPDATE_DISTRIBUTORS, []);
    },
    /**
     * Expected payload: {id, distributor}
     */
    [types.SET_DISTRIBUTOR]: ({commit, getters}, payload) => {
        let method = 'post';
        let data = payload.distributor;
        if (payload.id) {
            method = 'put';
            data = {
                [payload.distributor.id]: {
                    ...payload.distributor
                }
            }
        }
        axios[method](distributosResource, data)
            .then( res => {
                commit(types.UPDATE_DISTRIBUTOR, {
                        id: payload.id,
                        distributor: res.data,
                });
            }).catch( error => {
                console.log(error)
            });
    },
};